@@ -273,6 +273,42 @@ sub attach {
   $cv;
 }
 
+sub open_attachment {
+  my ( $self, $doc, $attachment, $options ) = @_;
+  my $cv = AnyEvent->condvar;
+
+  # passthrough handler without json encoding
+  my $success = sub {
+    $options->{success}->(@_) if ($options->{success});
+    $cv->send(@_);
+  };
+
+  # error handler that croaks with http headers
+  my $error = sub {
+    my $headers = shift;
+    $options->{error}->(@_) if ($options->{error});
+    $cv->croak(encode_json $headers);
+  };
+
+  my $cb = sub {
+    my ($body, $headers) = @_;
+    if ($headers->{Status} >= 200 and $headers->{Status} < 400) {
+      $success->(@_);
+    } else {
+      $error->($headers);
+    }
+  };
+
+  http_request(
+    GET => $self->uri
+        . uri_escape_utf8( $doc->{_id} ) . "/"
+        . uri_escape_utf8($attachment),
+    headers => $self->_build_headers($options),
+    $cb
+  );
+  $cv;
+}
+
 sub detach {
   my ( $self, $doc, $attachment, $options ) = @_;
   if ( $options->{success} ) {
@@ -424,7 +460,6 @@ sub put {
   $cv;
 }
 
-1;
 
 __END__
 
@@ -553,6 +588,15 @@ B<Example>:
 
   $db->detach($doc, "issue.net")->recv;
 
+=head3 $cv = $db->open_attachment($doc, $attachment)
+
+This method retrieves an attachment and returns the contents as a condvar.
+
+B<Example>:
+
+  my($body, $headers) = $db->open_attachment($doc, "issue.net")->recv;
+  my $content_type    = $headers->{'content-type'};
+
 =head3 $cv = $db->bulk_docs(\@docs, [ \%options ])
 
 This method requests that many create, update, and delete operations be
